import subprocess
import os, sys
_SUMATRAPATH = os.environ['PROGRAMFILES'] + '/SumatraPDF/SumatraPDF.exe'
if not os.path.exists(_SUMATRAPATH):
    print('Could not find SumatraPdf. Install it or fix sumatrapdf.py manually.')
    sys.exit()

_AHKPATH = os.path.dirname(os.path.abspath(__file__)) + '/AutoHotkey'

def _winact(pid):
    "activate a window having given pid"
    subprocess.Popen([_AHKPATH + '/AutoHotkey.exe',
        _AHKPATH + '/Lib/winact.ahk', str(pid)])

# The user may only be interested in the methods show() that opens the
# document or activates its window, optionally taking a page number, close()
# that closes the document, and perhaps isopen().

class SumatraPDF(object):
    "operations with SumatraPDF windows"
    def __init__(self, fname):
        self.filename = fname
        self.proc = None # Popen instance

    def open(self, page=None):
        "open the file in SumatraPDF"
        if type(page) is int:
            self.proc = subprocess.Popen([_SUMATRAPATH, self.filename,
                '-page', str(page)])
        else:
            self.proc = subprocess.Popen([_SUMATRAPATH, self.filename])

    def activate(self):
        "activate the window if the process is running"
        if self.proc:
            if self.proc.poll() == None:
                _winact(self.proc.pid)

    def isopen(self):
        'True or False depending on the state of the process'
        if self.proc == None:
            return False
        elif self.proc.poll() == None:
            return True
        else:
            self.proc = None
            return False

    def show(self, page=None):
        "open or activate the document's window"
        if self.isopen():
            self.activate()
            if type(page) is int:
                subprocess.Popen([
                    _SUMATRAPATH, self.filename,
                    '-reuse-instance',
                    '-page', str(page)])
        else:
            self.open(page=page)

    def close(self):
        "terminate the process"
        if self.proc != None:
            try:
                self.proc.terminate()
                self.proc = None
            except:
                print('Could not terminate the process.')
